@@ -239,7 +239,7 @@ class UnderscodeDecoder(object):
 
         elif state == 2:
             if inchar == '_':
-                (state, outchar) = (1, u'_')  # end of escape sequence
+                (state, outchar) = (1, u' ')  # end of escape sequence
             elif inchar in self._digits:
                 (state, outchar) = (1, unicode(inchar))  # end of esc. seq.
             elif inchar == 'x':
@@ -463,8 +463,8 @@ class UnderscodeEncoder(object):
         if offset == 0 and inchar in self._digits:
             return '_%c' % str(inchar)
 
-        # Encode underscores, but not ASCII-alphanumeric characters.
-        if inchar == u'_':
+        # Encode spaces, but not ASCII-alphanumeric characters.
+        if inchar == u' ':
             return '__'
         if inchar in self._alphanum:
             return str(inchar)
